Stan Math Library: stan/math/fwd/scal/fun/log_mix.hpp File Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

Namespaces | Functions
log_mix.hpp File Reference
`#include <stan/math/fwd/core.hpp>`
`#include <stan/math/prim/scal/fun/value_of.hpp>`
`#include <stan/math/prim/scal/fun/log_mix.hpp>`
`#include <boost/math/tools/promotion.hpp>`
`#include <cmath>`

Go to the source code of this file.

## Namespaces
| stan
| stan::math
| Matrices and templated mathematical functions.

## Functions
template<typename T_theta , typename T_lambda1 , typename T_lambda2 , int N>
void | stan::math::log_mix_partial_helper (const T_theta &theta, const T_lambda1 &lambda1, const T_lambda2 &lambda2, typename boost::math::tools::promote_args< T_theta, T_lambda1, T_lambda2 >::type(&partials_array)[N])
template<typename T >
fvar< T > | stan::math::log_mix (const fvar< T > &theta, const fvar< T > &lambda1, const fvar< T > &lambda2)
| Return the log mixture density with specified mixing proportion and log densities and its derivative at each. More...
template<typename T >
fvar< T > | stan::math::log_mix (const fvar< T > &theta, const fvar< T > &lambda1, const double lambda2)
template<typename T >
fvar< T > | stan::math::log_mix (const fvar< T > &theta, const double lambda1, const fvar< T > &lambda2)
template<typename T >
fvar< T > | stan::math::log_mix (const double theta, const fvar< T > &lambda1, const fvar< T > &lambda2)
template<typename T >
fvar< T > | stan::math::log_mix (const fvar< T > &theta, const double lambda1, const double lambda2)
template<typename T >
fvar< T > | stan::math::log_mix (const double theta, const fvar< T > &lambda1, const double lambda2)
template<typename T >
fvar< T > | stan::math::log_mix (const double theta, const double lambda1, const fvar< T > &lambda2)

[ Stan Home Page ] © 2011–2016, Stan Development Team.